list_of_lists_to_df: Parse list of lists specification into a data frame

list_of_lists_to_dfR Documentation

Parse list of lists specification into a data frame

Description

Parse list of lists specification into a data frame

Usage

list_of_lists_to_df(ll)

Arguments

ll

a list of lists

Value

a data frame with a row per list


csvwr documentation built on Nov. 21, 2022, 5:05 p.m.