| override_defaults | R Documentation |
Merges two lists applying override values on top of the default values.
override_defaults(...)
... |
any number of lists with configuration values |
a list with the values from the first list replacing those in the second and so on
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.